lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:   Wed, 28 Sep 2016 20:20:14 +0200
From:   Sergio Paracuellos <sergio.paracuellos@...il.com>
To:     gregkh@...uxfoundation.org
Cc:     devel@...verdev.osuosl.org, linux-kernel@...r.kernel.org
Subject: [PATCH 81/87] staging: wlang-ng: avoid new typedef: hfa384x_cmdresult_t

This patch fixes the following checkpatch.pl warning in hfa384x.h:
WARNING: do not add new typedefs

It applies for typedef hfa384x_cmdresult_t

Signed-off-by: Sergio Paracuellos <sergio.paracuellos@...il.com>
---
 drivers/staging/wlan-ng/hfa384x.h     |  6 +++---
 drivers/staging/wlan-ng/hfa384x_usb.c | 16 ++++++++--------
 2 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/drivers/staging/wlan-ng/hfa384x.h b/drivers/staging/wlan-ng/hfa384x.h
index 57c394d..a1a347c 100644
--- a/drivers/staging/wlan-ng/hfa384x.h
+++ b/drivers/staging/wlan-ng/hfa384x.h
@@ -1138,12 +1138,12 @@ struct hfa384x_pdrec {
  * ---  Also, a collection of support types --
  *--------------------------------------------------------------------
  */
-typedef struct hfa384x_statusresult {
+struct hfa384x_cmdresult {
 	u16 status;
 	u16 resp0;
 	u16 resp1;
 	u16 resp2;
-} hfa384x_cmdresult_t;
+};
 
 /* USB Control Exchange (CTLX):
  *  A queue of the structure below is maintained for all of the
@@ -1213,7 +1213,7 @@ typedef void (*ctlx_usercb_t) (struct hfa384x *hw,
 	u16 parm1;
 	u16 parm2;
 
-	hfa384x_cmdresult_t result;
+	struct hfa384x_cmdresult result;
 } hfa384x_metacmd_t;
 
 #define	MAX_GRP_ADDR		32
diff --git a/drivers/staging/wlan-ng/hfa384x_usb.c b/drivers/staging/wlan-ng/hfa384x_usb.c
index 9203880..1e5f74c 100644
--- a/drivers/staging/wlan-ng/hfa384x_usb.c
+++ b/drivers/staging/wlan-ng/hfa384x_usb.c
@@ -213,7 +213,7 @@ struct usbctlx_completor {
 
 static int
 usbctlx_get_status(const struct hfa384x_usb_statusresp *cmdresp,
-		   hfa384x_cmdresult_t *result);
+		   struct hfa384x_cmdresult *result);
 
 static void
 usbctlx_get_rridresult(const struct hfa384x_usb_rridresp *rridresp,
@@ -622,7 +622,7 @@ static hfa384x_usbctlx_t *usbctlx_alloc(void)
 
 static int
 usbctlx_get_status(const struct hfa384x_usb_statusresp *cmdresp,
-		   hfa384x_cmdresult_t *result)
+		   struct hfa384x_cmdresult *result)
 {
 	result->status = le16_to_cpu(cmdresp->status);
 	result->resp0 = le16_to_cpu(cmdresp->resp0);
@@ -647,13 +647,13 @@ static hfa384x_usbctlx_t *usbctlx_alloc(void)
 /*----------------------------------------------------------------
 * Completor object:
 * This completor must be passed to hfa384x_usbctlx_complete_sync()
 * when processing a CTLX that returns a hfa384x_cmdresult_t structure.
 ----------------------------------------------------------------*/
 struct usbctlx_cmd_completor {
 	struct usbctlx_completor head;
 
 	const struct hfa384x_usb_statusresp *cmdresp;
-	hfa384x_cmdresult_t *result;
+	struct hfa384x_cmdresult *result;
 };
 
 static inline int usbctlx_cmd_completor_fn(struct usbctlx_completor *head)
@@ -669,7 +669,7 @@ static inline struct usbctlx_completor *init_cmd_completor(
 							*completor,
 						const struct hfa384x_usb_statusresp
 							*cmdresp,
-						hfa384x_cmdresult_t *result)
+						struct hfa384x_cmdresult *result)
 {
 	completor->head.complete = usbctlx_cmd_completor_fn;
 	completor->cmdresp = cmdresp;
@@ -798,7 +798,7 @@ static inline struct usbctlx_completor *init_rmem_completor(
 static void hfa384x_cb_status(hfa384x_t *hw, const hfa384x_usbctlx_t *ctlx)
 {
 	if (ctlx->usercb) {
-		hfa384x_cmdresult_t cmdresult;
+		struct hfa384x_cmdresult cmdresult;
 
 		if (ctlx->state != CTLX_COMPLETE) {
 			memset(&cmdresult, 0, sizeof(cmdresult));
@@ -1497,7 +1497,7 @@ static int hfa384x_usbctlx_complete_sync(hfa384x_t *hw,
 		kfree(ctlx);
 	} else if (mode == DOWAIT) {
 		struct usbctlx_cmd_completor completor;
-		hfa384x_cmdresult_t wridresult;
+		struct hfa384x_cmdresult wridresult;
 
 		result = hfa384x_usbctlx_complete_sync(hw,
 						       ctlx,
@@ -1679,7 +1679,7 @@ static int hfa384x_usbctlx_complete_sync(hfa384x_t *hw,
 		kfree(ctlx);
 	} else if (mode == DOWAIT) {
 		struct usbctlx_cmd_completor completor;
-		hfa384x_cmdresult_t wmemresult;
+		struct hfa384x_cmdresult wmemresult;
 
 		result = hfa384x_usbctlx_complete_sync(hw,
 						       ctlx,
@@ -647,13 +647,13 @@ static hfa384x_usbctlx_t *usbctlx_alloc(void)
 * Completor object:
 * This completor must be passed to hfa384x_usbctlx_complete_sync()
-* when processing a CTLX that returns a hfa384x_cmdresult_t structure.
+* when processing a CTLX that returns a struct hfa384x_cmdresult structure.
 ----------------------------------------------------------------*/
 struct usbctlx_cmd_completor {
-- 
1.9.1

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ